Struct CriticalSectionRawMutex
pub struct CriticalSectionRawMutex { /* private fields */ }Expand description
A mutex that allows borrowing data across executors and interrupts.
Safety
This mutex is safe to share between different executors and interrupts.
Implementations
impl CriticalSectionRawMutex
impl CriticalSectionRawMutex
pub const fn new() -> CriticalSectionRawMutex
pub const fn new() -> CriticalSectionRawMutex
Create a new CriticalSectionRawMutex.