Signal

Struct Signal 

pub struct Signal<M, T>
where M: RawMutex,
{ /* private fields */ }
Single-slot signaling primitive for a single consumer.

This is similar to a Channel with a buffer size of 1, except “sending” to it (calling Signal::signal) when full will overwrite the previous value instead of waiting for the receiver to pop the previous value.

It is useful for sending data between tasks when the receiver only cares about the latest data, and therefore it’s fine to “lose” messages. This is often the case for “state” updates.

For more advanced use cases, you might want to use Channel instead. For multiple consumers, use Watch instead.

Signals are generally declared as statics and then borrowed as required.

use embassy_sync::signal::Signal;
use embassy_sync::blocking_mutex::raw::CriticalSectionRawMutex;

enum SomeCommand {
  On,
  Off,
}

static SOME_SIGNAL: Signal<CriticalSectionRawMutex, SomeCommand> = Signal::new();

Implementations



impl<M, T> Signal<M, T>
where M: RawMutex,

pub const fn new() -> Signal<M, T>

Create a new Signal.



impl<M, T> Signal<M, T>
where M: RawMutex,

pub fn signal(&self, val: T)

Mark this Signal as signaled.

pub fn reset(&self)

Remove the queued value in this Signal, if any.

pub fn wait(&self) -> impl Future<Output = T>

Future that completes when this Signal has been signaled, taking the value out of the signal.

The returned Future is cancel-safe. No value will be lost even if it isn’t polled to completion.

pub fn try_take(&self) -> Option<T>

non-blocking method to try and take the signal value.

pub fn signaled(&self) -> bool

non-blocking method to check whether this signal has been signaled. This does not clear the signal.